Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(273)

Unified Diff: content/renderer/media/android/stream_texture_factory.h

Issue 2192823004: Update StreamTextureProxy to accept a base::Closure (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fixed include guards Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/android/stream_texture_factory.h
diff --git a/content/renderer/media/android/stream_texture_factory.h b/content/renderer/media/android/stream_texture_factory.h
index cf1d874d8337c041680c2dc8595fe7187316703c..6abcc5da78a10b9eb7ef3a2e87837a99b7709cfc 100644
--- a/content/renderer/media/android/stream_texture_factory.h
+++ b/content/renderer/media/android/stream_texture_factory.h
@@ -40,7 +40,7 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
// a connected client will receive callbacks on. This can be called
watk 2016/07/29 19:03:16 update docs
tguilbert 2016/08/01 22:05:57 Done.
// on any thread, but must be called with the same loop every time.
void BindToLoop(int32_t stream_id,
watk 2016/07/29 19:03:16 tangential: we should rename this at some point to
tguilbert 2016/08/01 22:05:57 Done.
watk 2016/08/01 22:30:03 Thanks for doing it in this CL :)
- cc::VideoFrameProvider::Client* client,
+ const base::Closure& received_frame_cb,
scoped_refptr<base::SingleThreadTaskRunner> loop);
watk 2016/08/01 22:30:03 s/loop/task_runner
tguilbert 2016/08/01 23:03:18 Done.
// StreamTextureHost::Listener implementation:
@@ -58,9 +58,9 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
const std::unique_ptr<StreamTextureHost> host_;
// Protects access to |client_| and |loop_|.
base::Lock lock_;
- cc::VideoFrameProvider::Client* client_;
+ base::Closure received_frame_cb_;
scoped_refptr<base::SingleThreadTaskRunner> loop_;
watk 2016/08/01 22:30:03 s/loop_/task_runner_/ (and docs above)
tguilbert 2016/08/01 23:03:18 Done.
@@ -58,9 +58,9 @@ class StreamTextureProxy : public StreamTextureHost::Listener {
const std::unique_ptr<StreamTextureHost> host_;
- // Protects access to |client_| and |loop_|.
+ // Protects access to |received_frame_cb_| and |loop_|.
base::Lock lock_;
DISALLOW_IMPLICIT_CONSTRUCTORS(StreamTextureProxy);

Powered by Google App Engine
This is Rietveld 408576698